pitchtools.chromatic_pitch_name_to_octave_number
================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_name_to_octave_number.chromatic_pitch_name_to_octave_number
